# Go API client for apileague

API League is a Hub for World Class APIs.

## Overview
This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [OpenAPI-spec](https://www.openapis.org/) from a remote server, you can easily generate an API client.

- API version: 1.6.4
- Package version: 1.6.4
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.GoClientCodegen

## Installation

Install the following dependencies:

```sh
go get github.com/stretchr/testify/assert
go get golang.org/x/net/context
```

Put the package under your project folder and add the following in import:

```go
import apileague "github.com/ddsky/api-league-clients/tree/master/go/"
```

To use a proxy, set the environment variable `HTTP_PROXY`:

```go
os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")
```

## Configuration of Server URL

Default configuration comes with `Servers` field that contains server objects as defined in the OpenAPI specification.

### Select Server Configuration

For using other server than the one defined on index 0 set context value `apileague.ContextServerIndex` of type `int`.

```go
ctx := context.WithValue(context.Background(), apileague.ContextServerIndex, 1)
```

### Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value `apileague.ContextServerVariables` of type `map[string]string`.

```go
ctx := context.WithValue(context.Background(), apileague.ContextServerVariables, map[string]string{
	"basePath": "v2",
})
```

Note, enum values are always validated and all unused variables are silently ignored.

### URLs Configuration per Operation

Each operation can use different server URL defined using `OperationServers` map in the `Configuration`.
An operation is uniquely identified by `"{classname}Service.{nickname}"` string.
Similar rules for overriding default operation server index and variables applies by using `apileague.ContextOperationServerIndices` and `apileague.ContextOperationServerVariables` context maps.

```go
ctx := context.WithValue(context.Background(), apileague.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), apileague.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})
```

## Documentation for API Endpoints

All URIs are relative to *https://api.apileague.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArtAPI* | [**ImageToAsciiArtByURLAPI**](docs/ArtAPI.md#imagetoasciiartbyurlapi) | **Get** /convert-image-to-ascii-txt | Image to Ascii Art by URL API
*ArtAPI* | [**RandomPoemAPI**](docs/ArtAPI.md#randompoemapi) | **Get** /retrieve-random-poem | Random Poem API
*BooksAPI* | [**FindSimilarBooksAPI**](docs/BooksAPI.md#findsimilarbooksapi) | **Get** /list-similar-books | Find Similar Books API
*BooksAPI* | [**SearchBooksAPI**](docs/BooksAPI.md#searchbooksapi) | **Get** /search-books | Search Books API
*FoodAPI* | [**ComputeNutritionAPI**](docs/FoodAPI.md#computenutritionapi) | **Get** /compute-nutrition | Compute Nutrition API
*FoodAPI* | [**RetrieveRecipeInformationAPI**](docs/FoodAPI.md#retrieverecipeinformationapi) | **Get** /retrieve-recipe | Retrieve Recipe Information API
*FoodAPI* | [**SearchDrinksAPI**](docs/FoodAPI.md#searchdrinksapi) | **Get** /search-drinks | Search Drinks API
*FoodAPI* | [**SearchRecipesAPI**](docs/FoodAPI.md#searchrecipesapi) | **Get** /search-recipes | Search Recipes API
*FoodAPI* | [**SearchRestaurantsAPI**](docs/FoodAPI.md#searchrestaurantsapi) | **Get** /search-restaurants | Search Restaurants API
*HumorAPI* | [**GenerateNonsenseWordAPI**](docs/HumorAPI.md#generatenonsensewordapi) | **Get** /generate-nonsense-word | Generate Nonsense Word API
*HumorAPI* | [**RandomJokeAPI**](docs/HumorAPI.md#randomjokeapi) | **Get** /retrieve-random-joke | Random Joke API
*HumorAPI* | [**RandomMemeAPI**](docs/HumorAPI.md#randommemeapi) | **Get** /retrieve-random-meme | Random Meme API
*HumorAPI* | [**SearchGifsAPI**](docs/HumorAPI.md#searchgifsapi) | **Get** /search-gifs | Search Gifs API
*HumorAPI* | [**SearchJokesAPI**](docs/HumorAPI.md#searchjokesapi) | **Get** /search-jokes | Search Jokes API
*HumorAPI* | [**SearchMemesAPI**](docs/HumorAPI.md#searchmemesapi) | **Get** /search-memes | Search Memes API
*KnowledgeAPI* | [**RandomQuoteAPI**](docs/KnowledgeAPI.md#randomquoteapi) | **Get** /retrieve-random-quote | Random Quote API
*KnowledgeAPI* | [**RandomRiddleAPI**](docs/KnowledgeAPI.md#randomriddleapi) | **Get** /retrieve-random-riddle | Random Riddle API
*KnowledgeAPI* | [**RandomTriviaAPI**](docs/KnowledgeAPI.md#randomtriviaapi) | **Get** /retrieve-random-trivia | Random Trivia API
*MathAPI* | [**ConvertUnitsAPI**](docs/MathAPI.md#convertunitsapi) | **Get** /convert-units | Convert Units API
*MediaAPI* | [**DetectMainImageColorAPI**](docs/MediaAPI.md#detectmainimagecolorapi) | **Get** /detect-color | Detect Main Image Color API
*MediaAPI* | [**RescaleImageAPI**](docs/MediaAPI.md#rescaleimageapi) | **Get** /rescale-image | Rescale Image API
*MediaAPI* | [**SearchIconsAPI**](docs/MediaAPI.md#searchiconsapi) | **Get** /search-icons | Search Icons API
*MediaAPI* | [**SearchRoyaltyFreeImagesAPI**](docs/MediaAPI.md#searchroyaltyfreeimagesapi) | **Get** /search-images | Search Royalty Free Images API
*MediaAPI* | [**VectorSearchAPI**](docs/MediaAPI.md#vectorsearchapi) | **Get** /search-vectors | Vector Search API
*NewsAPI* | [**ExtractNewsAPI**](docs/NewsAPI.md#extractnewsapi) | **Get** /extract-news | Extract News API
*NewsAPI* | [**SearchNewsAPI**](docs/NewsAPI.md#searchnewsapi) | **Get** /search-news | Search News API
*NewsAPI* | [**TopNewsAPI**](docs/NewsAPI.md#topnewsapi) | **Get** /retrieve-top-news | Top News API
*StorageAPI* | [**ReadKeyValueFromStoreAPI**](docs/StorageAPI.md#readkeyvaluefromstoreapi) | **Get** /read-key-value | Read Key Value from Store API
*StorageAPI* | [**StoreKeyValueGETAPI**](docs/StorageAPI.md#storekeyvaluegetapi) | **Get** /store-key-value | Store Key Value (GET) API
*TextAPI* | [**CorrectSpellingAPI**](docs/TextAPI.md#correctspellingapi) | **Get** /correct-spelling | Correct Spelling API
*TextAPI* | [**DetectGenderByNameAPI**](docs/TextAPI.md#detectgenderbynameapi) | **Get** /detect-gender | Detect Gender by Name API
*TextAPI* | [**DetectLanguageAPI**](docs/TextAPI.md#detectlanguageapi) | **Get** /detect-language | Detect Language API
*TextAPI* | [**DetectSentimentAPI**](docs/TextAPI.md#detectsentimentapi) | **Get** /detect-sentiment | Detect Sentiment API
*TextAPI* | [**ExtractDatesAPI**](docs/TextAPI.md#extractdatesapi) | **Get** /extract-dates | Extract Dates API
*TextAPI* | [**ExtractEntitiesAPI**](docs/TextAPI.md#extractentitiesapi) | **Get** /extract-entities | Extract Entities API
*TextAPI* | [**ListWordSynonymsAPI**](docs/TextAPI.md#listwordsynonymsapi) | **Get** /list-synonyms | List Word Synonyms API
*TextAPI* | [**PluralizeWordAPI**](docs/TextAPI.md#pluralizewordapi) | **Get** /pluralize-word | Pluralize Word API
*TextAPI* | [**ScoreReadabilityAPI**](docs/TextAPI.md#scorereadabilityapi) | **Get** /score-readability | Score Readability API
*TextAPI* | [**ScoreTextAPI**](docs/TextAPI.md#scoretextapi) | **Get** /score-text | Score Text API
*TextAPI* | [**SingularizeWordAPI**](docs/TextAPI.md#singularizewordapi) | **Get** /singularize-word | Singularize Word API
*TextAPI* | [**StemTextAPI**](docs/TextAPI.md#stemtextapi) | **Get** /stem-text | Stem Text API
*TextAPI* | [**TagPartOfSpeechAPI**](docs/TextAPI.md#tagpartofspeechapi) | **Get** /tag-pos | Tag Part of Speech API
*WebAPI* | [**ExtractAuthorsAPI**](docs/WebAPI.md#extractauthorsapi) | **Get** /extract-authors | Extract Authors API
*WebAPI* | [**ExtractContentFromAWebPageAPI**](docs/WebAPI.md#extractcontentfromawebpageapi) | **Get** /extract-content | Extract Content from a Web Page API
*WebAPI* | [**ExtractPublishDateAPI**](docs/WebAPI.md#extractpublishdateapi) | **Get** /extract-publish-date | Extract Publish Date API
*WebAPI* | [**RetrievePageRankAPI**](docs/WebAPI.md#retrievepagerankapi) | **Get** /retrieve-page-rank | Retrieve Page Rank API
*WebAPI* | [**SearchWebAPI**](docs/WebAPI.md#searchwebapi) | **Get** /search-web | Search Web API
*WebAPI* | [**VerifyEmailAddressAPI**](docs/WebAPI.md#verifyemailaddressapi) | **Get** /verify-email | Verify Email Address API


## Documentation For Models

 - [ComputeNutritionAPI200Response](docs/ComputeNutritionAPI200Response.md)
 - [ComputeNutritionAPI200ResponseIngredientBreakdownInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInner.md)
 - [ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner.md)
 - [ConvertUnitsAPI200Response](docs/ConvertUnitsAPI200Response.md)
 - [CorrectSpellingAPI200Response](docs/CorrectSpellingAPI200Response.md)
 - [DetectGenderByNameAPI200Response](docs/DetectGenderByNameAPI200Response.md)
 - [DetectLanguageAPI200ResponseInner](docs/DetectLanguageAPI200ResponseInner.md)
 - [DetectMainImageColorAPI200ResponseInner](docs/DetectMainImageColorAPI200ResponseInner.md)
 - [DetectSentimentAPI200Response](docs/DetectSentimentAPI200Response.md)
 - [DetectSentimentAPI200ResponseDocument](docs/DetectSentimentAPI200ResponseDocument.md)
 - [DetectSentimentAPI200ResponseSentencesInner](docs/DetectSentimentAPI200ResponseSentencesInner.md)
 - [ExtractAuthorsAPI200Response](docs/ExtractAuthorsAPI200Response.md)
 - [ExtractAuthorsAPI200ResponseAuthorsInner](docs/ExtractAuthorsAPI200ResponseAuthorsInner.md)
 - [ExtractContentFromAWebPageAPI200Response](docs/ExtractContentFromAWebPageAPI200Response.md)
 - [ExtractDatesAPI200Response](docs/ExtractDatesAPI200Response.md)
 - [ExtractDatesAPI200ResponseDatesInner](docs/ExtractDatesAPI200ResponseDatesInner.md)
 - [ExtractEntitiesAPI200Response](docs/ExtractEntitiesAPI200Response.md)
 - [ExtractEntitiesAPI200ResponseEntitiesInner](docs/ExtractEntitiesAPI200ResponseEntitiesInner.md)
 - [ExtractNewsAPI200Response](docs/ExtractNewsAPI200Response.md)
 - [ExtractNewsAPI200ResponseImagesInner](docs/ExtractNewsAPI200ResponseImagesInner.md)
 - [ExtractNewsAPI200ResponseVideosInner](docs/ExtractNewsAPI200ResponseVideosInner.md)
 - [ExtractPublishDateAPI200Response](docs/ExtractPublishDateAPI200Response.md)
 - [FindSimilarBooksAPI200Response](docs/FindSimilarBooksAPI200Response.md)
 - [GenerateNonsenseWordAPI200Response](docs/GenerateNonsenseWordAPI200Response.md)
 - [ListWordSynonymsAPI200Response](docs/ListWordSynonymsAPI200Response.md)
 - [PluralizeWordAPI200Response](docs/PluralizeWordAPI200Response.md)
 - [RandomMemeAPI200Response](docs/RandomMemeAPI200Response.md)
 - [RandomPoemAPI200Response](docs/RandomPoemAPI200Response.md)
 - [RandomQuoteAPI200Response](docs/RandomQuoteAPI200Response.md)
 - [RandomRiddleAPI200Response](docs/RandomRiddleAPI200Response.md)
 - [RandomTriviaAPI200Response](docs/RandomTriviaAPI200Response.md)
 - [ReadKeyValueFromStoreAPI200Response](docs/ReadKeyValueFromStoreAPI200Response.md)
 - [RetrievePageRankAPI200Response](docs/RetrievePageRankAPI200Response.md)
 - [RetrieveRecipeInformationAPI200Response](docs/RetrieveRecipeInformationAPI200Response.md)
 - [RetrieveRecipeInformationAPI200ResponseCredits](docs/RetrieveRecipeInformationAPI200ResponseCredits.md)
 - [RetrieveRecipeInformationAPI200ResponseDietaryProperties](docs/RetrieveRecipeInformationAPI200ResponseDietaryProperties.md)
 - [RetrieveRecipeInformationAPI200ResponseIngredientsInner](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInner.md)
 - [RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures.md)
 - [RetrieveRecipeInformationAPI200ResponseInstructionsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInner.md)
 - [RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner.md)
 - [RetrieveRecipeInformationAPI200ResponseNutrition](docs/RetrieveRecipeInformationAPI200ResponseNutrition.md)
 - [RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner](docs/RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner.md)
 - [RetrieveRecipeInformationAPI200ResponseScores](docs/RetrieveRecipeInformationAPI200ResponseScores.md)
 - [RetrieveRecipeInformationAPI200ResponseTaste](docs/RetrieveRecipeInformationAPI200ResponseTaste.md)
 - [RetrieveRecipeInformationAPI200ResponseTimes](docs/RetrieveRecipeInformationAPI200ResponseTimes.md)
 - [ScoreReadabilityAPI200Response](docs/ScoreReadabilityAPI200Response.md)
 - [ScoreTextAPI200Response](docs/ScoreTextAPI200Response.md)
 - [ScoreTextAPI200ResponseInterestingness](docs/ScoreTextAPI200ResponseInterestingness.md)
 - [ScoreTextAPI200ResponseInterestingnessSubscores](docs/ScoreTextAPI200ResponseInterestingnessSubscores.md)
 - [ScoreTextAPI200ResponseReadability](docs/ScoreTextAPI200ResponseReadability.md)
 - [ScoreTextAPI200ResponseReadabilityMainscores](docs/ScoreTextAPI200ResponseReadabilityMainscores.md)
 - [ScoreTextAPI200ResponseReadabilitySubscores](docs/ScoreTextAPI200ResponseReadabilitySubscores.md)
 - [ScoreTextAPI200ResponseSkimmability](docs/ScoreTextAPI200ResponseSkimmability.md)
 - [ScoreTextAPI200ResponseSkimmabilityMainscores](docs/ScoreTextAPI200ResponseSkimmabilityMainscores.md)
 - [ScoreTextAPI200ResponseSkimmabilitySubscores](docs/ScoreTextAPI200ResponseSkimmabilitySubscores.md)
 - [ScoreTextAPI200ResponseStyle](docs/ScoreTextAPI200ResponseStyle.md)
 - [ScoreTextAPI200ResponseStyleSubscores](docs/ScoreTextAPI200ResponseStyleSubscores.md)
 - [SearchBooksAPI200Response](docs/SearchBooksAPI200Response.md)
 - [SearchBooksAPI200ResponseBooksInnerInner](docs/SearchBooksAPI200ResponseBooksInnerInner.md)
 - [SearchDrinksAPI200Response](docs/SearchDrinksAPI200Response.md)
 - [SearchDrinksAPI200ResponseDrinksInner](docs/SearchDrinksAPI200ResponseDrinksInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerCredits](docs/SearchDrinksAPI200ResponseDrinksInnerCredits.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs.md)
 - [SearchDrinksAPI200ResponseDrinksInnerInstructionsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutrition](docs/SearchDrinksAPI200ResponseDrinksInnerNutrition.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing.md)
 - [SearchGifsAPI200Response](docs/SearchGifsAPI200Response.md)
 - [SearchGifsAPI200ResponseImagesInner](docs/SearchGifsAPI200ResponseImagesInner.md)
 - [SearchIconsAPI200Response](docs/SearchIconsAPI200Response.md)
 - [SearchJokesAPI200Response](docs/SearchJokesAPI200Response.md)
 - [SearchJokesAPI200ResponseJokesInner](docs/SearchJokesAPI200ResponseJokesInner.md)
 - [SearchMemesAPI200Response](docs/SearchMemesAPI200Response.md)
 - [SearchMemesAPI200ResponseMemesInner](docs/SearchMemesAPI200ResponseMemesInner.md)
 - [SearchNewsAPI200Response](docs/SearchNewsAPI200Response.md)
 - [SearchNewsAPI200ResponseNewsInner](docs/SearchNewsAPI200ResponseNewsInner.md)
 - [SearchRecipesAPI200Response](docs/SearchRecipesAPI200Response.md)
 - [SearchRecipesAPI200ResponseRecipesInner](docs/SearchRecipesAPI200ResponseRecipesInner.md)
 - [SearchRecipesAPI200ResponseRecipesInnerNutrition](docs/SearchRecipesAPI200ResponseRecipesInnerNutrition.md)
 - [SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner](docs/SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner.md)
 - [SearchRestaurantsAPI200Response](docs/SearchRestaurantsAPI200Response.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInner](docs/SearchRestaurantsAPI200ResponseRestaurantsInner.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInnerAddress](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerAddress.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [SearchRoyaltyFreeImagesAPI200Response](docs/SearchRoyaltyFreeImagesAPI200Response.md)
 - [SearchRoyaltyFreeImagesAPI200ResponseImagesInner](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInner.md)
 - [SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense.md)
 - [SearchWebAPI200Response](docs/SearchWebAPI200Response.md)
 - [SearchWebAPI200ResponseResultsInner](docs/SearchWebAPI200ResponseResultsInner.md)
 - [SingularizeWordAPI200Response](docs/SingularizeWordAPI200Response.md)
 - [StemTextAPI200Response](docs/StemTextAPI200Response.md)
 - [StoreKeyValueGETAPI200Response](docs/StoreKeyValueGETAPI200Response.md)
 - [TagPartOfSpeechAPI200Response](docs/TagPartOfSpeechAPI200Response.md)
 - [TopNewsAPI200Response](docs/TopNewsAPI200Response.md)
 - [TopNewsAPI200ResponseTopNewsInner](docs/TopNewsAPI200ResponseTopNewsInner.md)
 - [TopNewsAPI200ResponseTopNewsInnerNewsInner](docs/TopNewsAPI200ResponseTopNewsInnerNewsInner.md)
 - [VectorSearchAPI200Response](docs/VectorSearchAPI200Response.md)
 - [VectorSearchAPI200ResponseVectorsInner](docs/VectorSearchAPI200ResponseVectorsInner.md)
 - [VerifyEmailAddressAPI200Response](docs/VerifyEmailAddressAPI200Response.md)


## Documentation For Authorization


Authentication schemes defined for the API:
### apiKey

- **Type**: API key
- **API key parameter name**: api-key
- **Location**: URL query string

Note, each API key must be added to a map of `map[string]APIKey` where the key is: api-key and passed in as the auth context for each request.

Example

```go
auth := context.WithValue(
		context.Background(),
		apileague.ContextAPIKeys,
		map[string]apileague.APIKey{
			"api-key": {Key: "API_KEY_STRING"},
		},
	)
r, err := client.Service.Operation(auth, args)
```

### headerApiKey

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

Note, each API key must be added to a map of `map[string]APIKey` where the key is: x-api-key and passed in as the auth context for each request.

Example

```go
auth := context.WithValue(
		context.Background(),
		apileague.ContextAPIKeys,
		map[string]apileague.APIKey{
			"x-api-key": {Key: "API_KEY_STRING"},
		},
	)
r, err := client.Service.Operation(auth, args)
```


## Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains
a number of utility functions to easily obtain pointers to values of basic types.
Each of these functions takes a value of the given basic type and returns a pointer to it:

* `PtrBool`
* `PtrInt`
* `PtrInt32`
* `PtrInt64`
* `PtrFloat`
* `PtrFloat32`
* `PtrFloat64`
* `PtrString`
* `PtrTime`

## Author

mail@apileague.com

